@@ -35,7 +35,7 @@ var (
 	delimiter      string
 )
 
-var cavctl_version = "1.3.0"
+var cavctl_version = "1.5.0"
 
 // rootCmd represents the base command when called without any subcommands
 var rootCmd = &cobra.Command{
@@ -86,8 +86,8 @@ func init() {
 	rootCmd.PersistentFlags().BoolVar(&expand, "expand", false, "Expand result")
 	rootCmd.PersistentFlags().StringVarP(&format, "format", "f", "json", "Output format : json, yaml, txt")
 	rootCmd.PersistentFlags().StringVar(&search, "search", "", "Search filter")
-	rootCmd.PersistentFlags().IntVar(&page, "page", 1, "Page number")
-	rootCmd.PersistentFlags().IntVar(&size, "size", 10, "Page size")
+	rootCmd.PersistentFlags().IntVar(&page, "page", 0, "Page number")
+	rootCmd.PersistentFlags().IntVar(&size, "size", 0, "Page size")
 	rootCmd.PersistentFlags().StringVar(&schema, "schema", "", "Schema filter")
 	rootCmd.PersistentFlags().StringVar(&file, "file", "", "File path for import/export operations")
 	rootCmd.PersistentFlags().StringVar(&pipeline, "pipeline", "", "Pipeline name for data transformation")
@@ -116,9 +116,9 @@ func initializeConfig(cmd *cobra.Command) error {
 		cobra.CheckErr(err)
 
 		// Search for a config file with the name "config" (without extension).
-		viper.AddConfigPath(".")
+		// NOTE: Don't search in current directory "." to avoid reading the binary itself
 		viper.AddConfigPath(home + "/.cavaliba")
-		viper.SetConfigName("cavctl")
+		viper.SetConfigName("default")
 		viper.SetConfigType("yaml")
 	}
 
