@@ -15,6 +15,8 @@ urlpatterns = [
     path('', api.ping.index, name='api'),   
     path('ping/', api.ping.ping, name='api_ping'),
 
+    # test
+    path('test/', api.testapi.testapi, name='api_test'),
     
     path('version/', api.version.version, name='api_version'),
     path('info/', api.info.info, name='api_info'),
