@@ -1183,8 +1183,8 @@ class Instance:
         # ,"p_read","p_update","p_delete
         for fieldname in self.ordered_fields():
             field = self.fields[fieldname]
-            if field.is_multi():
-                continue
+            # if field.is_multi():
+                # continue
             if field.is_injected:
                 continue
             if fieldname.startswith('_'):
@@ -1602,23 +1602,21 @@ def load_schema(datadict=None, verbose=True, aaa=None):
          datadict['keyname']  : mandatory classname(!) 
     
     OUT:
-        schema  => schema
-        True    => success (delete, ...)
-        False   => failed
+        None or error string
     '''
 
 
     if not datadict:
-        return
+        return "load_schema: no data"
 
     if not has_schema_write_permission(aaa=aaa):
         log(WARNING, aaa=aaa, app="data", view="schema", action="load", status="DENY", data=_("Not allowed")) 
-        return
+        return "load_schema: not allowed"
 
     #  for a _schema, classname is the provided keyname (classname = _schema)
     classname = datadict.get("keyname", None)
     if not classname: 
-        return
+        return f"load_schema: missing classname {datadict}"
 
     action = datadict.get("_action", "create")
 
@@ -1626,30 +1624,39 @@ def load_schema(datadict=None, verbose=True, aaa=None):
     if action == 'delete':
         # TODO: check classname is not builtin (_reserved)
         schema_obj = Schema.delete(classname)
-        return schema_obj
+        if schema_obj:
+            return
+        else:
+            return f"load_schema: failed to delete {classname}"
 
     #  enable
     elif action == "enable":
         # TODO: check classname is not builtin (_reserved)
         schema_obj = Schema.enable(classname)
-        return schema_obj
+        if schema_obj:
+            return
+        else:
+            return f"load_schema: failed to enable {classname}"
     
     # disable 
     elif action == "disable":
         # TODO: check classname is not builtin (_reserved)
         schema_obj = Schema.disable(classname)
-        return schema_obj
+        if schema_obj:
+            return
+        else:
+            return f"load_schema: failed to disable {classname}"
 
         
     # init 
     elif action == "init":
         if Schema.exists(classname):
-            return True       
+            return
         schema = Schema()
         schema.update_from_dict(datadict, verbose=verbose)
         schema.save()
-        return schema
-
+        # TODO: check save result
+        return
 
     # create (or update)
     elif action == "create":
@@ -1658,417 +1665,59 @@ def load_schema(datadict=None, verbose=True, aaa=None):
             schema = Schema()
         schema.update_from_dict(datadict, verbose=verbose)
         schema.save()
-        return schema
+        return
 
     # update (only)
     elif action == "update":
         schema = Schema.from_name(classname)
         if not schema:
-            return False
+            return f"load_schema: not found: {classname} "
         schema.update_from_dict(datadict, verbose=verbose)
         schema.save()
-        return schema
-
+        return
 
     else:
         log(WARNING, aaa=aaa, app="data", view="schema", action='unknown', 
             status="FAILED", data=f"Unknown load action {action} for schema {classname}") 
 
 
-    return False
+    return f"load_schema: unknown action {action} for {classname}"
 
 
 
 
-
-
-
-
-
-# def load_schema(datadict=None, verbose=True, aaa=None):
-
-#     # DEPRECATED: options, icon,  p_* 
-#     META = ["keyname", "displayname", "is_enabled", "_options", "_sections",
-#             "icon", "order", "page", "options",
-#             "p_read", "p_create", "p_update", "p_delete", "p_admin",
-#             ]
-
-
-#     if not datadict:
-#         return
-
-#     if not aaa:
-#         log(WARNING, aaa=aaa, app="data", view="schema", action="load", status="DENY", data=_("Not allowed")) 
-#         return
-
-#     #  for a _schema, classname is the provided keyname (classname = _schema)
-#     classname = datadict.get("keyname", None)
-#     if not classname: 
-#         return
-
-#     schema_obj = load_schema_part(classname, datadict, verbose=verbose, aaa=aaa)
-#     if not schema_obj:
-#         return
-
-#     # fields
-#     for fieldname, fielddata in datadict.items():
-#         if fieldname in META:
-#             continue      
-#         load_field_definition(classname, fieldname, fielddata, verbose=verbose, aaa=aaa)
-
-#     return schema_obj
-
-
-# # loads class definition (fields not loaded here)
-# def load_schema_part(classname, classdata, verbose=True, aaa=None):
-
-#     if not type(classname) is str:
-#         return
-
-#     if not type(classdata) is dict:
-#         return
-
-#     if not len(classname)>0: 
-#         return
-
-#     if not aaa:
-#         log(WARNING, aaa=aaa, app="data", view="class", action="load", status="DENY", data=_("Not allowed")) 
-#         return   
-   
-#     # action = force_action
-#     # if not action:
-#     action = classdata.get("_action", "create")
-
-#     # No cache, direct access for Load
-#     schema_obj = DataClass.objects.filter(keyname=classname).first()
-
-#     if action == "delete":
-#         if not Schema.has_schema_delete_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="schema", action=action, status="DENY", data=_("Not allowed")) 
-#             return schema_obj
-#         if schema_obj:
-#             schema_obj.delete()
-#             cache.cache2_schema.delete(classname)
-#             return schema_obj
-#         else:
-#             return
-
-#     elif action == "disable":
-#         if not Schema.has_schema_update_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="schema", action=action, status="DENY", data=_("Not allowed")) 
-#             return schema_obj
-#         if schema_obj:
-#             schema_obj.is_enabled = False
-#             schema_obj.save()
-#             cache.cache2_schema.delete(classname)
-#             return schema_obj
-
-#     elif action == "enable":
-#         if not Schema.has_schema_update_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="schema", action=action, status="DENY", data=_("Not allowed")) 
-#             return schema_obj
-#         if schema_obj:
-#             schema_obj.is_enabled = True
-#             schema_obj.save()
-#             cache.cache2_schema.delete(classname)
-#             return schema_obj
-
-#     elif action == "update":
-#         if not Schema.has_schema_update_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="schema", action=action, status="DENY", data=_("Not allowed")) 
-#             return schema_obj
-#         # no creation, see below
-
-#     elif action == "init":
-#         if not Schema.has_schema_create_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="schema", action=action, status="DENY", data=_("Not allowed"))
-#             return schema_obj
-#         # skip if already created
-#         if schema_obj:
-#             # return None to skip creating fields
-#             return schema_obj
-#         schema_obj=DataClass(keyname=classname)
-#         schema_obj.save()
-#         cache.cache2_schema.delete(classname)
-
-#     elif action == "create":
-#         if not Schema.has_schema_create_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="schema", action=action, status="DENY", data=_("Not allowed")) 
-#             return schema_obj
-#         if not schema_obj:    
-#             schema_obj=DataClass(keyname=classname)
-#             schema_obj.save()
-#             cache.cache2_schema.delete(classname)
-#     else:
-#         # unknown action
-#         log(WARNING, aaa=aaa, app="data", view="schema", action="unknown", status="DENY", data=_("Unknown action")) 
-#         if verbose:
-#             print(f"  !!! unknown action {action} for class {classname}")
-#         return schema_obj
-
-
-
-
-
-
-#     # update for all remaining actions
-#     # --------------------------------
-#     if not Schema.has_schema_update_permission(aaa=aaa):
-#         log(WARNING, aaa=aaa, app="data", view="schema", action="update", status="DENY", data=_("Unknown action")) 
-#         return schema_obj
-
-#     if not schema_obj:
-#         return
-
-#     if "displayname" in classdata:
-#         schema_obj.displayname = classdata.get("displayname","")
-
-#     if "order" in classdata:
-#         schema_obj.order = classdata.get("order",100)
-
-#     if "page" in classdata:
-#         schema_obj.page = classdata.get("page")
-
-#     if "is_enabled" in classdata:
-#         schema_obj.is_enabled = classdata.get("is_enabled") in TRUE_LIST
-
-
-#     # update permissions ; 3.19- => deprecated
-#     if "p_read" in classdata:
-#         schema_obj.p_read = classdata.get("p_read")
-#     if "p_create" in classdata:
-#         schema_obj.p_create = classdata.get("p_create")
-#     if "p_update" in classdata:
-#         schema_obj.p_update = classdata.get("p_update")
-#     if "p_delete" in classdata:
-#         schema_obj.p_delete = classdata.get("p_delete")
-#     if "p_admin" in classdata:
-#         schema_obj.p_admin = classdata.get("p_admin")
-
-#     # new 3.20 _options builtin YAML structure
-#     # ----------------------------------------
-#     options = classdata.get("_options", {})
-#     # copy YAML in DB Text field
-
-#     #  TODO: bugfix : missing options from classdata are removed from obj
-#     # migrate to Schema save with all options
-#     schema_obj.options = yaml.dump(options, allow_unicode=True, sort_keys=True)
-
-#     # permissions V3.20+
-#     if "p_read" in options:
-#         schema_obj.p_read = options.get("p_read")
-#     if "p_create" in options:
-#         schema_obj.p_create = options.get("p_create")
-#     if "p_update" in options:
-#         schema_obj.p_update = options.get("p_update")
-#     if "p_delete" in options:
-#         schema_obj.p_delete = options.get("p_delete")
-#     if "p_admin" in options:
-#         schema_obj.p_admin = options.get("p_admin")
-
-
-#     schema_obj.save()
-#     cache.cache2_schema.delete(classname)
-
-#     log(INFO, aaa=aaa, app="data", view="schema", action=action, status="OK", data=f"{classname}")
-
-#     return schema_obj
-
-
-
-# # load Schema fields in DB
-# def load_field_definition(classname, fieldname, fielddata, verbose=True, aaa=None):
-
-#     # TODO ? refuse to load for a non-existent Class 
-
-
-#     if not type(fieldname) is str:
-#         return
-
-#     if not type(fielddata) is dict:
-#         return
-
-#     if not len(fieldname)>0: 
-#         return
-
-#     if not aaa:
-#         log(WARNING, aaa=aaa, app="data", view="field_def", action="load", status="DENY", data=_("Not allowed")) 
-#         return
-    
-#     action = fielddata.get("_action", "create")
-
-#     fieldobj = DataSchema.objects.filter(classname=classname, keyname=fieldname).first()
-
-#     if action == "delete":
-#         if not Schema.has_schemafield_delete_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="field_def", action="delete", status="DENY", data=_("Not allowed")) 
-#             return        
-#         if fieldobj:
-#             fieldobj.delete()
-#             cache.cache2_schema.delete(classname)
-#             if verbose:
-#                 print(f"  field delete - {classname}:{fieldname}")            
-#             return fieldobj
-
-#     elif action == "disable":
-#         if not Schema.has_schemafield_update_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="field_def", action="disable", status="DENY", data=_("Not allowed")) 
-#             return        
-#         if fieldobj:
-#             fieldobj.is_enabled = False
-#             fieldobj.save()
-#             cache.cache2_schema.delete(classname)
-#             if verbose:
-#                 print(f"  field disable - {classname}:{fieldname}")            
-#             return fieldobj
-
-#     elif action == "enable":
-#         if not Schema.has_schemafield_update_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="field_def", action="enable", status="DENY", data=_("Not allowed")) 
-#             return        
-#         if fieldobj:
-#             fieldobj.is_enabled = True
-#             fieldobj.save()
-#             cache.cache2_schema.delete(classname)
-#             if verbose:
-#                 print(f"  field enable - {classname}:{fieldname}")            
-#             return fieldobj
-
-#     elif action == "update":
-#         if not Schema.has_schemafield_update_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="field_def", action="update", status="DENY", data=_("Not allowed")) 
-#             return        
-#         # no creation, see below for update
-#         if not fieldobj:
-#             return
-
-#     elif action == "init":
-#         if not Schema.has_schemafield_create_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="field_def", action="init", status="DENY", data=_("Not allowed"))
-#             return
-#         # skip if already created
-#         if fieldobj:
-#             return fieldobj
-#         fieldobj = DataSchema()
-#         fieldobj.classname = classname
-#         fieldobj.keyname = fieldname
-#         fieldobj.save()
-#         cache.cache2_schema.delete(classname)
-#         if verbose:
-#             print(f"  field init - {classname}:{fieldname}")            
-
-
-#     elif action == "create":
-#         if not Schema.has_schemafield_create_permission(aaa=aaa):
-#             log(WARNING, aaa=aaa, app="data", view="field_def", action="create", status="DENY", data=_("Not allowed")) 
-#             return
-    
-#         if not fieldobj:
-#             fieldobj = DataSchema()
-#             fieldobj.classname = classname
-#             fieldobj.keyname = fieldname
-#             fieldobj.default = fielddata.get("default", "")
-#             fieldobj.save()
-#             cache.cache2_schema.delete(classname)
-#             if verbose:
-#                 print(f"  field create - {classname}:{fieldname}")            
-#     else: 
-#         # unknown action
-#         log(WARNING, aaa=aaa, app="data", view="field_def", action="unknown", status="DENY", data=_("Unknown action")) 
-#         if verbose:
-#             print(f"  ERR unknown field action: {action} for {classname}:{fieldname}")
-#         return fieldobj
-
-
-#     # update provided params if provided only !
-#     if not fieldobj:
-#         return
-
-#     if not Schema.has_schemafield_update_permission(aaa=aaa):
-#         log(WARNING, aaa=aaa, app="data", view="field_def", action="update", status="DENY", data=_("Not allowed")) 
-#         return
-
-#     if "displayname" in fielddata:
-#         fieldobj.displayname = fielddata.get("displayname")
-
-#     if "description" in fielddata:
-#         fieldobj.description = fielddata.get("description")
-
-#     if "is_enabled" in fielddata:
-#         fieldobj.is_enabled = fielddata.get("is_enabled") in TRUE_LIST
-
-#     if "order" in fielddata:
-#         fieldobj.order = int( fielddata.get("order") )
-#     if "page" in fielddata:
-#         fieldobj.page = fielddata.get("page")
-
-#     if "dataformat" in fielddata:
-#         fieldobj.dataformat = fielddata.get("dataformat")
-
-#     if "dataformat_ext" in fielddata:
-#         fieldobj.dataformat_ext = fielddata.get("dataformat_ext")
-#     if "default" in fielddata:
-#         fieldobj.default_value = fielddata.get("default")
-#     if "cardinal_min" in fielddata:
-#         fieldobj.cardinal_min = int( fielddata.get("cardinal_min") )
-#     if "cardinal_max" in fielddata:
-#         fieldobj.cardinal_max = int( fielddata.get("cardinal_max") )
-
-#     fieldobj.save()
-#     cache.cache2_schema.delete(classname)
-
-#     log(INFO, aaa=aaa, app="data", view="field_def", action=action, status="OK", data=f"{classname} - {fieldname}")
-
-#     if verbose:
-#         print(f"  field update - {classname}:{fieldname}")
-#     return fieldobj
-
-
-
-def load_instance(datadict=None, verbose=True, aaa=None):
+def load_instance(datadict=None, aaa=None):
 
     if not datadict:
-        return
+        return f"load_instance: no data"
 
     if not aaa:
         log(WARNING, aaa=aaa, app="data", view="instance", action="load", status="DENY", data=_("Not allowed")) 
-        return
+        return f"load_instance: not allowed"
     
     classname = datadict.get("classname", None)
     schema = Schema.from_name(classname)
     if not schema:
-        print(f"ERR - unknown schema: {classname}")
-        return
+        return f"load_instance: schema not found: {classname}"
 
     action = datadict.get("_action", "create")
 
     keyname = datadict.get("keyname", None)
 
-    # instance = Instance.from_keyname(classname=classname, keyname=keyname)
-    # if not instance:
-    #     log(WARNING, aaa=aaa, app="data", view="instance", action="load", status="KO", data=f"couldn't create {classname}")
-    #     return
-   
-    # #  auto or from_field... : keyname not mandatory in datadict
-    # if instance.schema.keyname_mode == 'edit':
-    #     if not keyname: 
-    #         print(f"ERR - missing keyname for {classname}: {datadict}")
-    #         return
 
+    verbose = None
 
     if action == "delete":
         instance = Instance.from_keyname(classname=classname, keyname=keyname, expand=False)
         if instance:
             if instance.has_delete_permission(aaa=aaa):
                 instance.delete()
-                if verbose:
-                    print(f"instance ({action}) - {classname}:{keyname}")
-                return instance
+                return
             else:
                 log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Not allowed"))
         else:
             log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Not found"))
-        return
+        return f"load_instance: delete failed for {classname}:{keyname}"
 
 
     elif action == "disable":
@@ -2076,14 +1725,12 @@ def load_instance(datadict=None, verbose=True, aaa=None):
         if instance:
             if instance.has_update_permission(aaa=aaa):
                 instance.disable()
-                if verbose:
-                    print(f"instance ({action}) - {classname}:{keyname}")
-                return instance
+                return
             else:
                 log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Not allowed"))
         else:
             log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Not found"))
-        return
+        return f"load_instance: disable failed for {classname}:{keyname}"
 
 
     elif action == "enable":
@@ -2091,14 +1738,12 @@ def load_instance(datadict=None, verbose=True, aaa=None):
         if instance:
             if instance.has_update_permission(aaa=aaa):
                 instance.enable()
-                if verbose:
-                    print(f"instance ({action}) - {classname}:{keyname}")
-                return instance
+                return
             else:
                 log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Not allowed"))
         else:
             log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Not found"))
-        return
+        return f"load_instance: enable failed for {classname}:{keyname}"
             
 
     # init only == new instance if doesn't already exist
@@ -2112,14 +1757,13 @@ def load_instance(datadict=None, verbose=True, aaa=None):
             if schema.has_create_permission(aaa):
                 instance.merge_import(datadict)
                 instance.init()
-                if verbose:
-                    print(f"instance ({action}) - {classname}:{keyname}")
-                return instance
+                return
             else:
                 log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Not allowed"))
+                return f"load_instance: init not allowed for {classname}:{keyname}"
         else:
             log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Couldn't create"))
-        return
+        return f"load_instance: init failed for {classname}:{keyname}"
     
 
     # create and/or update if exists
@@ -2131,14 +1775,13 @@ def load_instance(datadict=None, verbose=True, aaa=None):
             if schema.has_create_permission(aaa):
                 instance.merge_import(datadict)
                 instance.create()
-                if verbose:
-                    print(f"instance ({action}) - c={classname} k={instance.keyname} h={instance.id}")                
-                return instance
+                return
             else:
                 log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Not allowed"))
+                return f"load_instance: create not allowed for {classname}:{keyname}"
         else:
             log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Couldn't create"))
-        return
+        return f"load_instance: create failed for {classname}:{keyname}"
 
 
     # don't create, update only if exists
@@ -2148,19 +1791,19 @@ def load_instance(datadict=None, verbose=True, aaa=None):
             if instance.has_update_permission(aaa=aaa):
                 instance.merge_import(datadict)
                 instance.update()
-                if verbose:
-                    print(f"instance ({action}) - {classname}:{keyname}")                
-                return instance
+                return
             else:
                 log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Not allowed"))
+                return f"load_instance: update not allowed for {classname}:{keyname}"
         else:
             log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Not found"))
-        return
+        return f"load_instance: update failed for {classname}:{keyname}"
 
     # unknown action
     else:
         log(WARNING, aaa=aaa, app="data", view="instance", action=action, status="DENY", data=_("Unknown action"))
-        return
+    
+    return f"load_instance: unknown action {action} for {classname}:{keyname}"
 
 
   
