@@ -29,94 +29,99 @@ from app_data.pipeline import get_pipeline
 # ---------------------------------------------------------------------
 # Load broker for one or more objects provided as a LIST of DICTs
 # ---------------------------------------------------------------------
-def load_broker(datalist=None, aaa=None, force_action=None, verbose=False, progress=False):
+def load_broker(datalist=None, aaa=None, force_action=None):
 
+    '''
+    Load a batch of object into the database
+
+    IN:
+       datalist: [ {}, {}, {}, ... ] 
+       aaa:
+       force_action:
+    
+    OUT:
+       reply struct (dict) : count, count_ok, count_ko, errors=[]
+    '''
+
+    reply = {
+        'count': 0,
+        'count_ok': 0,
+        'count_ko': 0,
+        'errors':  [],
+    }
 
     if not datalist:
-        if verbose:
-            print("ERR - load_broker - no data provided")
-        return 0
+        reply['errors'].append("no data provided")
+        return reply
         
     if not type(datalist) is list:
-        print("ERR - load_broker - data provided is not a list")
-        return 0
+        reply['errors'].append("invalid data provided (not a list)")
+        return reply
 
     if not aaa:
-        print("ERR - load_broker - no aaa permission provided")
-        return 0
+        reply['errors'].append("missing identity")
+        return reply
     
     if 'perms' not in aaa:
-        print("ERR - load_broker - invalid aaa permissions")
-        return 0
+        reply['errors'].append("missing aaa permissions")
+        return reply
 
-    count = 0 
 
     for datadict in datalist:
         
-        r = None
+        err = None
+
+        reply['count'] += 1
 
         if not type(datadict) is dict:
-            print(f"ERR - load_broker - invalid entry: {datadict}")
+            reply['count_ko'] += 1
+            reply['errors'].append(f"invalid entry: {datadict}")
             continue
 
         classname = datadict.get("classname", None)
         if not classname:
-            # unknown object class : NEXT : log error
-            print(f"ERR - load_broker - no classname provided for {datadict}")
+            reply['count_ko'] += 1
+            reply['errors'].append(f"missing classname in {datadict}")
             continue
+
         if len(classname) == 0:
             # unknown object class : NEXT : log error
-            print(f"ERR - load_broker - bad classname provided for {datadict}")
+            reply['count_ko'] += 1
+            reply['errors'].append(f"invalid classname in {datadict}")
             continue
         
-        #  backward compatibility  with _user objects (keyname may be login)
-        keyname = datadict.get("keyname", None)
-        if not keyname:
-            if classname == "_user":
-                login = datadict.get("login", None)
-                if login:
-                    datadict["keyname"] = login
-            #     else:
-            #         print(f"ERR - load_broker - no keyname/login for {datadict}")
-            #         continue
-            # else:
-            #     print(f"ERR - load_broker - no keyname for {datadict}")
-            #     continue
-
         if force_action:
             datadict["_action"] = force_action
 
         if classname == "_user":
-            r = load_user(datadict=datadict, verbose=verbose, aaa=aaa)
+            err = load_user(datadict=datadict, aaa=aaa)
 
         elif classname == "_schema":
-            r = load_schema(datadict=datadict, verbose=verbose, aaa=aaa)
+            err = load_schema(datadict=datadict, aaa=aaa)
 
         elif classname == "_group":
-            r = load_group(datadict=datadict,verbose=verbose, aaa=aaa)
+            err = load_group(datadict=datadict, aaa=aaa)
 
         elif classname == "_role":
-            r = load_role(datadict=datadict,verbose=verbose, aaa=aaa)
+            err = load_role(datadict=datadict, aaa=aaa)
 
         elif classname == "_permission":
-            r = load_permission(datadict=datadict,verbose=verbose, aaa=aaa)            
+            err = load_permission(datadict=datadict, aaa=aaa)            
 
         elif classname == "_home":
-            r = load_home(datadict=datadict, verbose=verbose, aaa=aaa)
+            err = load_home(datadict=datadict, aaa=aaa)
 
         else:
             # internal or user-defined Instance
-            r = load_instance(datadict=datadict, verbose=verbose, aaa=aaa)
+            err = load_instance(datadict=datadict, aaa=aaa)
 
-        if r:
-            count += 1
+        if err:
+            reply['count_ko'] += 1
+            reply['errors'].append(err)
+        else:
+            reply['count_ok'] += 1
 
-        if progress:
-            if count % 100 == 0:
-                print(f"{count} done")
-
-
-    return count
+    return reply
 
 # ---------------------------------------------------------------------
 # CSV File to DATA
@@ -357,7 +362,7 @@ def load_file_yaml(file=None, filename=None, pipeline=None, verbose=None):
             try:
                 data = yaml.load(f, Loader=yaml.SafeLoader)
             except Exception as e:
-                print(f"SKIP - YAM syntax error in {filename} : ", e)
+                print(f"SKIP - YAML syntax error in {filename} : ", e)
 
     if not type(data) is list:
         print(f"SKIP - invalid YAML, not a LIST ({filename})")
