@@ -4,6 +4,7 @@ import uuid
 import copy
 import yaml
 import sys
+import json
 
 from django.forms.models import model_to_dict
 
@@ -443,6 +444,7 @@ class Schema:
         
         # default to all-class permission
         if "p_data_read" in aaa["perms"]:
+            
             return True
 
 
@@ -510,74 +512,70 @@ class Schema:
 
     # -------
 
-    def to_yaml(self):
-        ''' return as nice YAML text'''
-        r = []
+    def to_dict(self):
 
-        r.append("- classname: _schema")
+        reply = {}
 
-        head = {}
-        head['keyname'] = self.classname
+        reply["classname"] = "_schema"
+        reply['keyname'] = self.classname
         if self.displayname and len(self.displayname) > 0:
-            head['displayname'] = self.displayname
-        if not self.is_enabled:
-            head['is_enabled'] = False
+            reply['displayname'] = self.displayname
+        if self.is_enabled:
+            reply['is_enabled'] = True
+        else:
+            reply['is_enabled'] = False
 
-        zz = yaml.dump(head, allow_unicode=True, sort_keys=False)
-        for l in zz.splitlines():
-            r.append("  " + l)
 
-        
-        r.append("")
-        
-        r.append("  _options:")
-        options = {}
+        reply["_options"] = {}
+
         if self.icon and len(self.icon) > 0:
-            options['icon'] = self.icon
-        options['keyname_mode'] = self.keyname_mode
+            reply["_options"]['icon'] = self.icon
+
+        reply["_options"]['keyname_mode'] = self.keyname_mode
+
         if self.keyname_label and len(self.keyname_label) > 0:
-            options['keyname_label'] = self.keyname_label
+            reply["_options"]['keyname_label'] = self.keyname_label
+
         if self.displayname_label and len(self.displayname_label) > 0:
-            options['displayname_label'] = self.displayname_label
+            reply["_options"]['displayname_label'] = self.displayname_label
+        
         if self.p_admin and len(self.p_admin) > 0:
-            options['p_admin'] = self.p_admin
+            reply["_options"]['p_admin'] = self.p_admin
+
         if self.p_create and len(self.p_create) > 0:
-            options['p_create'] = self.p_create
+            reply["_options"]['p_create'] = self.p_create
+
         if self.p_read and len(self.p_read) > 0:
-            options['p_read'] = self.p_read
+            reply["_options"]['p_read'] = self.p_read
+
         if self.p_update and len(self.p_update) > 0:
-            options['p_update'] = self.p_update
+            reply["_options"]['p_update'] = self.p_update
+
         if self.p_delete and len(self.p_delete) > 0:
-            options['p_delete'] = self.p_delete
+            reply["_options"]['p_delete'] = self.p_delete
 
+        # NEXT: sections
 
-        ydump = yaml.dump(options, allow_unicode=True, sort_keys=False)
-        for l in ydump.splitlines():
-            r.append("    " + l)
-
-
-        current_page = None
-        for page in self.ordered_fields:                # self.ordered_fields['page'][order] = [fieldname, ]
+        # fields
+        # self.ordered_fields['page'][order] = [fieldname, ]
+        for page in self.ordered_fields:
             for order in self.ordered_fields[page]:
                 for keyname in self.ordered_fields[page][order]:
                     field = self.fields[keyname]
-
-                    if page != current_page:
-                        r.append("")
-                        r.append("  # --- " + page)
-                        current_page = page
-
-                    r.append("")
-                    r.append("  " + keyname + ':')
-
-                    ydump = yaml.dump(field, allow_unicode=True, sort_keys=False)
-                    for l in ydump.splitlines():
-                        r.append("    " + l)
-
+                    reply[keyname] = field
             
-        return '\n'.join(r)
+        return reply
+    
 
+    def to_yaml(self):
+        content = [self.to_dict()]
+        return yaml.dump(content, allow_unicode=True, sort_keys=False, default_flow_style=False)
 
+    def to_json(self):
+        content = [self.to_dict()]
+        return json.dumps(content, indent=2, ensure_ascii=False).encode('utf8')
+
+    # ---
 
     def save(self):
         ''' save self to DataClass DB '''
