@@ -137,7 +137,7 @@ def instance_list(request, classname=None):
         instance = Instance(iobj=iobj, expand=True)
         if not instance.has_read_permission(aaa=aaa):
             continue
-        iobj.datapoints = dataview.filter(instance=instance)
+        iobj.datapoints = dataview.filter(instance=instance, mode="datapoint")
         filtered.append(iobj)
 
 
@@ -572,7 +572,7 @@ def data_export(request):
             if not instance.has_read_permission(aaa=aaa):
                 continue
             if dataview:
-                datapoints = dataview.filter(instance=instance, value_only=True)
+                datapoints = dataview.filter(instance=instance, mode='value')
                 data = dict(zip(columns_array, datapoints))
             else:
                 data = instance.get_dict_for_export()            
@@ -591,7 +591,7 @@ def data_export(request):
             if not instance.has_read_permission(aaa=aaa):
                 continue
             if dataview:
-                datapoints = dataview.filter(instance=instance, value_only=True)
+                datapoints = dataview.filter(instance=instance, mode='value')
                 data = dict(zip(columns_array, datapoints))
             else:
                 data = instance.get_dict_for_export()            
@@ -608,22 +608,29 @@ def data_export(request):
         response['Content-Disposition'] = 'attachment; filename="data.csv"'
         writer = csv.writer(response, delimiter=delimiter)
 
-        try:
-            instance = Instance(iobj=db_instances[0], expand=True)
-        except:
-            return response
+        # try:
+        #     instance = Instance(iobj=db_instances[0], expand=True)
+        # except:
+        #     return response
         
-        csv_columns = instance.get_csv_columns()
-
-        writer.writerow(csv_columns)
+        csv_columns = None
+        if dataview:
+            csv_columns = dataview.get_columns()
+            writer.writerow(csv_columns)
 
         for iobj in db_instances:
             instance = Instance(iobj=iobj, expand=True)
             if not instance:
                 continue            
+            if not csv_columns:
+                csv_columns = instance.get_csv_columns()
+                writer.writerow(csv_columns)         
             if not instance.has_read_permission(aaa=aaa):
                 continue
-            line = instance.get_csv_line(csv_columns)
+            if dataview:
+                line = dataview.filter(instance=instance, mode='csv')
+            else:
+                line = instance.get_csv_line(csv_columns)
             writer.writerow(line)
         return response
     
