@@ -12,7 +12,7 @@ CONFIGURATION_DEFAULT = {
 
 	"home": {
 		"GLOBAL_APPNAME": "Cavaliba",
-	    "CSV_DELIMITER": '|',
+	    "CSV_DELIMITER": ',',
 	    "LOGO_SIZE": 0,
 	    "LOG_DEBUG": "yes", 
 	    #"LOG_KEEP_DAYS": 31,
