@@ -16,23 +16,22 @@ from app_user.permission import permission_get_by_name
 def load_home(datadict=None, verbose=None, aaa=None):
 
     if not datadict:
-        return
+        return "load_home: no data"
 
     if not aaa:
         log(WARNING, aaa=aaa, app="home", view="load", action="", status="DENY", data=_("Not allowed")) 
-        return
+        return "load_home: no aaa"
 
     if not 'p_home_admin' in aaa['perms']:
         log(WARNING, aaa=aaa, app="home", view="load", action="", status="DENY", data=_("Not allowed")) 
-        return
+        return "load_home: not allowed"
 
     keyname = datadict.get("keyname", None)
     if not keyname: 
-        return
+        return "load_home: no keyname"
 
     action = datadict.get("_action", "create")
 
-    r = None
 
     dbentry = DashboardApp.objects.filter(keyname=keyname).first()
 
@@ -104,12 +103,10 @@ def load_home(datadict=None, verbose=None, aaa=None):
 
     if dbentry:
         log(INFO, aaa=aaa, app="home", view="load", action=action, status="OK", data=keyname)
-        if verbose:
-            print(f"dashboard: {action} - {keyname}")
+        return
+    
     else:
         log(INFO, aaa=aaa, app="home", view="load", action=action, status="KO", data=keyname)
-        if verbose:
-            print(f"dashboard: {action} - {keyname} - KO")
-
-    return dbentry
+        return f"load_home: {action} failed for {keyname}"
 
+    
