@@ -6,6 +6,7 @@ import os
 import sys
 import json
 import yaml
+import pprint
 
 
 from django.core.management.base import BaseCommand, CommandError
@@ -530,9 +531,14 @@ class Command(BaseCommand):
                     aaa = {}
                     aaa["perms"] = permission_all_keynames()
 
-                    r = load_broker(datalist, aaa=aaa, force_action=force_action, verbose=verbose, progress=progress)
+                    result = load_broker(datalist, aaa=aaa, force_action=force_action)
+                    
                     #if verbose:
-                    self.stdout.write(f"Loaded: {r} objects")
+                        #pprint.pprint(result)
+                        #print(result)
+                    self.stdout.write(json.dumps(result, indent=2, ensure_ascii=False))
+                    
+                    
                 else:
                     self.stdout.write("Dryrun : no DB action")
 
