@@ -3,7 +3,6 @@
 from django.urls import path
 
 from app_home import views
-from app_home import api
 
 # url namespace
 app_name="app_home"
@@ -31,14 +30,4 @@ urlpatterns = [
     path('private/admintools/revision/', views.admintools_revision, name='admintools_revision'),
 
 
-    # api ; in descending order
-    path('api/', api.index, name='api_home_index'),
-    path('api/version/', api.version, name='api_version'),
-    # path('api/classes/', api.classes, name='api_classes'),
-    # path('api/c/<slug:classname>/', api.classname, name='api_classname'),
-    # path('api/c/<slug:classname>/i/<slug:keyname>/', api.instance, name='api_instance'),
-    # path('api/import/', api.api_import, name='api_import'),
-    # path('api/csv/<slug:classname>/', api.api_csv, name='api_csv'),
-
-
 ]
\ No newline at end of file
