@@ -29,25 +29,26 @@ class SMSForm(forms.Form):
 
 class MessageUpdateForm(forms.Form):
 
-    archive = forms.BooleanField(required=False,
-        label=_("Archive message"),
-        initial = False
-        )
-
 
     has_email = forms.BooleanField(required=False,
-        label=_("Email Notification"),
+        label=_("Send email"),
         initial = False
         )
 
     has_sms = forms.BooleanField(required=False,
-        label=_("SMS Notification"),
+        label=_("Send SMS"),
         initial = False
         )
 
+    sms_content = forms.CharField(max_length=140, required=False,
+        label=_("SMS content"),
+        widget=forms.Textarea(attrs={'cols':80, 'rows':2})
+        #widget=TinyMCE(attrs={'cols': 60, 'rows': 30})
+        )
+
 
     content = forms.CharField(max_length=5000, required=False,
-        label=_("Message update"),
+        label=_("Message"),
         #widget=forms.Textarea(attrs={'cols':80})
         widget=TinyMCE(attrs={'cols': 60, 'rows': 30})
         )
