@@ -26,10 +26,18 @@ urlpatterns = [
     path('private/', views.private_list, name='private'),
     path('private/detail/<int:id>/', views.private_detail, name='detail'),
     path('private/update/<int:id>/',  views.update, name='update'),
+    path('private/close/<int:id>/',  views.close, name='close'),
+    path('private/close_all/', views.close_all, name='close_all'),
     path('private/reopen/<int:id>/',  views.reopen, name='reopen'),
-    path('private/flushall/', views.flushall_view, name='flushall'),
     path('private/archive/', views.archive, name='archive'),
 
+    # new message
+    path('private/new/',  views.new_message, name='new_message'),
+    path('private/new/<int:id>/',  views.new_message, name='new_message'),
+
+    # AJAX endpoints
+    path('private/ajax/template-list/', views.template_list_ajax, name='template_list'),
+    path('private/ajax/notify-summary/', views.notify_summary_ajax, name='notify_summary'),
 
     # API
     path('api/', api_views.index, name='api_index'),
