@@ -55,8 +55,6 @@ from app_sirene.forms import MessageUpdateForm
 # public
 #-----------------------------------------
 
-#  cache for X sec
-#@cache_page(2)
 def index(request):
 
     context = start_view(request, app="sirene", view="public") 
@@ -251,10 +249,11 @@ def anon_detail(request, id=None):
 def private_list(request):
 
     context = start_view(request, app="sirene", view="message_list", 
-        noauth="app_sirene:index", perm="p_sirene_access", noauthz="app_sirene:private",
+        noauth="app_sirene:index", perm="p_sirene_access", noauthz="app_sirene:index",
         # explicitly allow visitor
         visitor = True  
         )
+    
     if context["redirect"]:
         return redirect(context["redirect"])
     aaa = context["aaa"]
