@@ -301,43 +301,41 @@ def group_init(data):
 
     keyname = data.get('keyname', None)
     if not keyname:
-        return
+        return None, "group_init: missing keyname"
 
     # check if exists as role (not group)
     entry0 = SireneGroup.objects.filter(keyname=keyname, is_role=True).first()
     if entry0:
-        return
+        return None, f"group_init: already exists as role {keyname}"
 
     # skip if exists
     entry = group_get_by_name(keyname)
     if entry:
-        return entry
+        return entry, None
 
     entry = SireneGroup(is_role=False)
-    entry = group_update(entry, data)
-
-    return entry
+    return group_update(entry, data)
+ 
 
 
 def group_create(data):
 
     keyname = data.get('keyname', None)
     if not keyname:
-        return
+        return None, "group_create: missing keyname"
 
     # check if exists as role (not group)
     entry0 = SireneGroup.objects.filter(keyname=keyname, is_role=True).first()
     if entry0:
-        return
+        return None, f"group_create: already exists as role {keyname}"
 
     # create or update
     entry1 = group_get_by_name(keyname)
     if not entry1:
         entry1 = SireneGroup(is_role=False)
 
-    entry = group_update(entry1, data)
+    return group_update(entry1, data)
 
-    return entry
 
 
 def group_update(group, data):
@@ -351,7 +349,7 @@ def group_update(group, data):
 
 
     if not data:
-        return
+        return None, "group_update: no data"
 
     for attrib in attributs:
         if attrib in data:
@@ -411,7 +409,7 @@ def group_update(group, data):
     #                 group.permissions.add(perm2)
     #     group.save()    
 
-    return group
+    return group, None
 
 
 
@@ -420,34 +418,32 @@ def group_update_by_data(data):
     group = group_get_by_data(data)
     if group:
         return group_update(group, data)
+    return None, "group_update: group not found"
 
 
 # X
 def group_delete(gobj):
 
     if not gobj:
-        return False
+        return None, "group_delete:  error"
 
     if gobj.is_builtin:
-        return False
+        return None, "group_delete: is builtin"
 
     if gobj.is_role:
-        return False
+        return None, "group_delete: is role"
     
     try:
         gobj.delete()
-        return gobj
+        return gobj, None
     except Exception as e:
-        #print("group_delete failed : ",e)
-        return False
+        return None, f"group_delete: {e}"
 
 # X
 def group_delete_by_id(gid):
 
     gobj = group_get_by_id(gid)
-    r = group_delete(gobj)
-    return gobj
-
+    return group_delete(gobj)
 
 # X
 def group_delete_by_data(data):
@@ -455,6 +451,7 @@ def group_delete_by_data(data):
     group = group_get_by_data(data)
     if group:
         return group_delete_by_id(group.id)
+    return None, "group_delete: not found"
 
 # 0
 def group_enable_by_data(data):
@@ -462,7 +459,8 @@ def group_enable_by_data(data):
     if group:
         group.is_enabled = True
         group.save()
-        return group
+        return group, None
+    return None, "group_enable: not found"
 
 # 0
 def group_disable_by_data(data):
@@ -470,80 +468,74 @@ def group_disable_by_data(data):
     if group:
         group.is_enabled = False
         group.save()
-        return group
-    
+        return group, None
+    return None, "group_disable: not found"
+
 # -------------------------------------------------------
 # IMPORTS
 # -------------------------------------------------------
-def load_group(datadict=None, verbose=None, aaa=None):
+def load_group(datadict=None, aaa=None):
 
     if not datadict:
-        return
+        return f"load_group: missing data"
 
     if not aaa:
         log(WARNING, aaa=aaa, app="iam", view="group", action="load", status="DENY", data=_("Not allowed")) 
-        return
+        return f"load_group: not allowed"
 
     keyname = datadict.get("keyname", None)
     if not keyname: 
-        return
+        return f"load_group: missing keyname"
 
     action = datadict.get("_action", "create")
 
-    r = None
+    err = None
 
     if action == "init":
         if not has_group_create_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="group", action="init", status="DENY", data=_("Not allowed")) 
-            return
+            return f"load_group: init not allowed"
         # create/update only if not already exists
-        r = group_init(datadict)
+        g , err = group_init(datadict)
 
     elif action == "create":
         if not has_group_create_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="group", action="create", status="DENY", data=_("Not allowed")) 
-            return
+            return f"load_group: create not allowed for {keyname}"
         # create and/or update
-        r = group_create(datadict)
-        #r = group_update_by_data(datadict)
+        g, err = group_create(datadict)
 
     elif action == "update":
         if not has_group_update_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="group", action="update", status="DENY", data=_("Not allowed")) 
-            return
+            return f"load_group: update not allowed for {keyname}"
         # update only if exists
-        r = group_update_by_data(datadict)
+        g , err = group_update_by_data(datadict)
 
     elif action == "delete":
         if not has_group_delete_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="group", action="delete", status="DENY", data=_("Not allowed")) 
-            return
-        r = group_delete_by_data(datadict)
+            return f"load_group: delete not allowed for {keyname}"
+        g, err = group_delete_by_data(datadict)
 
     elif action == "enable":
         if not has_group_update_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="group", action="update", status="DENY", data=_("Not allowed")) 
-            return
-        r = group_enable_by_data(datadict)
+            return f"load_group: enable not allowed for {keyname}"
+        g, err = group_enable_by_data(datadict)
 
     elif action == "disable":
         if not has_group_update_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="group", action="update", status="DENY", data=_("Not allowed")) 
-            return
-        r = group_disable_by_data(datadict)
+            return f"load_group: disable not allowed for {keyname}"
+        g, err = group_disable_by_data(datadict)
 
     else:
-        pass
-
-    if r:
-        log(INFO, aaa=aaa, app="iam", view="group", action=action, status="OK", data=keyname)
-    else:
-        log(INFO, aaa=aaa, app="iam", view="group", action=action, status="KO", data=keyname)
-    if verbose:
-        print(f"group: {action} - {keyname} - {r}")
-
-    return r
+        return f"load_group: failed for {keyname} , action {action}"
 
+    if err:
+        return f"load_group: {err}"
+    return
 
 # -------------------------------------------------------
 # EXPORTs
