@@ -3,32 +3,13 @@
 
 import os
 from datetime import datetime, timedelta
-import time
-import base64
-import random
-import csv
-import jwt
-import json
-import re
 
-import pprint
 
-from django.utils import timezone
-from django.conf import settings
 from django.shortcuts import render, redirect
-from django.http import HttpResponse
-from django.contrib import messages
 from django.utils.translation import gettext as _
-from django.db.models import Q
-from django.contrib.auth import logout as django_logout
 
-import app_home.cache as cache
-from app_home.configuration import get_configuration
 from app_home.log import log, DEBUG, INFO, WARNING, ERROR, CRITICAL
 
-from .models import SireneUser
-from .models import SireneGroup
-
 from .aaa import start_view
 
 from .permission import permission_get_all
