@@ -168,32 +168,31 @@ def user_init(data):
 
     login = data.get('login', None)
     if not login:
-        return
+        return None, "user_init: no login"
 
     # skip if exists
     entry = user_get_by_login(login)
     if entry:
-        return entry
+        return entry, None
         
     entry = SireneUser()
-    entry = user_update(entry, data)
-    return entry
+    return user_update(entry, data)
+
 
 
 def user_create(data):
 
     login = data.get('login', None)
     if not login:
-        return
+        return None, "user_create: no login"
 
     # create or update
     entry1 = user_get_by_login(login)
     if not entry1:
         entry1 = SireneUser()
 
-    entry = user_update(entry1, data)
-    return entry
-
+    return user_update(entry1, data)
+    
 
 def user_update(user, data):
     ''' update user Object with data dict info'''
@@ -234,7 +233,7 @@ def user_update(user, data):
     user.save()
     cache.cache2_iam_user.clear()
 
-    return user
+    return user, None
 
 
 
@@ -254,7 +253,9 @@ def user_switch(user, is_enabled):
         user.last_update = timezone.now()
         user.save()
         cache.cache2_iam_user.clear()
-    return user
+        return user, None
+    else:
+        return None, "user_switch: missing user"
 
 def user_enable_by_id(userid):
     user = user_get_by_id(userid)
@@ -279,11 +280,13 @@ def user_delete(user):
     if user:
         if user.login == "admin":
             # built-in, can't delete ; disable instead
-            return
+            return None, "user_delete: can't delete admin"
         else:
             user.delete()
             cache.cache2_iam_user.clear()
-        return user        
+            return user, None
+    else:
+        return None, "user_delete: missing user"
 
 def user_delete_by_id(userid):
     user = user_get_by_id(userid)
@@ -302,73 +305,70 @@ def user_delete_by_data(data):
 def load_user(datadict=None, verbose=None, aaa=None):
 
     if not datadict:
-        return
+        return "load_user: missing data"
 
     if not aaa:
         log(WARNING, aaa=aaa, app="iam", view="user", action="load", status="DENY", data=_("Not allowed")) 
-        return
-    
+        return "load_user: missing aaa"
+
+
     keyname = datadict.get("keyname", None)
+    # backward compatibility : login field accepted as keyname
+    if not keyname:
+        keyname = datadict.get("login", None)
     if not keyname: 
-        return
+        return "load_user: missing keyname/login"
     
     if "login" not in datadict:
         datadict["login"] = keyname
 
     action = datadict.get("_action", "create")
 
-    r = None
+    err = None
 
     if action == "init":
         if not has_user_create_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="user", action="init", status="DENY", data=_("Not allowed")) 
-            return
-        r = user_init(datadict)
+            return "load_user: not allowed"
+        u, err = user_init(datadict)
 
     elif action == "create":
         if not has_user_create_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="user", action="create", status="DENY", data=_("Not allowed")) 
-            return        
-        r = user_create(datadict)
+            return "load_user: not allowed"
+        u, err = user_create(datadict)
 
     elif action == "update":
         if not has_user_update_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="user", action="update", status="DENY", data=_("Not allowed")) 
-            return        
-        r = user_update_by_data(datadict)
+            return "load_user: not allowed"
+        u, err = user_update_by_data(datadict)
 
     elif action == "delete":
         if not has_user_delete_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="user", action="delete", status="DENY", data=_("Not allowed")) 
-            return        
-        r = user_delete_by_data(datadict)
+            return "load_user: not allowed"
+        u, err = user_delete_by_data(datadict)
 
     elif action == "enable":
         if not has_user_update_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="user", action="update", status="DENY", data=_("Not allowed")) 
-            return        
-        r = user_enable_by_data(datadict)
+            return "load_user: not allowed"
+        u, err = user_enable_by_data(datadict)
 
     elif action == "disable":
         if not has_user_update_permission(aaa=aaa):
             log(WARNING, aaa=aaa, app="iam", view="user", action="update", status="DENY", data=_("Not allowed")) 
-            return        
-        r = user_disable_by_data(datadict)
-
-    # elif action == "append":
-    # NEXT : append only provided sub-elements
+            return "load_user: not allowed"
+        u, err = user_disable_by_data(datadict)
     else:
-        return
+        return f"load_user: unknown action {action}"
+
+    if err:
+        return f"load_user: {err}"
+    return
 
-    login = datadict["login"]
-    if r:
-        log(INFO, aaa=aaa, app="iam", view="user", action=action, status="OK", data=login)
-    else:
-        log(INFO, aaa=aaa, app="iam", view="user", action=action, status="KO", data=login)
-    if verbose:
-        print(f"load_user: {action} - {login} - {r}")
 
-    return r
 
 
 # -------------------------------------------------------
