@@ -37,6 +37,11 @@ CAVALIBA_DEBUG_AAA = os.environ.get("CAVALIBA_DEBUG_AAA","no")
 CAVALIBA_FILESTORE = os.environ.get("CAVALIBA_FILESTORE","/app/files/filestore/")
 
 
+# Max SIZE
+
+DATA_UPLOAD_MAX_MEMORY_SIZE=50000000
+FILE_UPLOAD_MAX_MEMORY_SIZE=50000000
+
 # -------------------------------------------------------------------
 # Application definition
 # -------------------------------------------------------------------
