@@ -43,7 +43,7 @@ def add_test_sites(count=5):
     yaml_str = '\n'.join(yaml_entries)
     datalist = yaml.safe_load(yaml_str)
     aaa = {'perms': ['p_data_create', 'p_data_site_admin']}
-    load_broker(datalist=datalist, aaa=aaa, verbose=False)
+    _ = load_broker(datalist=datalist, aaa=aaa)
 
 def add_test_apps(count=5):
     """Create test app entries (app01, app02, etc.)"""
@@ -55,7 +55,7 @@ def add_test_apps(count=5):
     yaml_str = '\n'.join(yaml_entries)
     datalist = yaml.safe_load(yaml_str)
     aaa = {'perms': ['p_data_create', 'p_data_app_admin']}
-    load_broker(datalist=datalist, aaa=aaa, verbose=False)
+    _ = load_broker(datalist=datalist, aaa=aaa)
 
 # ---------------------------------------------------------------------------
 # schema
@@ -100,7 +100,7 @@ def add_schema(classname='unittest',
     aaa = {'perms': [
         'p_schema_write',
         ]}
-    load_broker(datalist=datalist, aaa=aaa, verbose=verbose)
+    load_broker(datalist=datalist, aaa=aaa)
 
     from app_data.schema import Schema
     return Schema.from_name(classname)
@@ -135,7 +135,7 @@ def add_instance(classname=None,
         'p_data_admin',
         ]}
     
-    load_broker(datalist=datalist, aaa=aaa, verbose=verbose)
+    load_broker(datalist=datalist, aaa=aaa)
 
 
 
@@ -167,7 +167,7 @@ def add_schema_field(classname='test', fields={}, verbose=False):
     aaa = {'perms': [
         'p_schema_write',
         ]}
-    load_broker(datalist=datalist, aaa=aaa, verbose=verbose)
+    load_broker(datalist=datalist, aaa=aaa)
 
 
 
@@ -194,7 +194,7 @@ def add_pipeline_noop():
                 - field_noop
         ''')
     aaa = {'perms':['p_pipeline_create']}
-    load_broker(datalist=datalist, aaa=aaa, verbose=False)
+    load_broker(datalist=datalist, aaa=aaa)
 
 
 
