@@ -124,7 +124,7 @@ class TestDataClass(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_schema_write']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = DataClass.objects.filter(keyname='test1').first()
         self.assertIsNone(classobj)
@@ -138,7 +138,7 @@ class TestDataClass(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_unknown_permission']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = DataClass.objects.filter(keyname='test1').first()
         self.assertIsNotNone(classobj)
@@ -153,7 +153,7 @@ class TestDataClass(TestCase):
             ''')
         aaa = {'perms': ['p_schema_write']}
 
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
         classobj = DataClass.objects.filter(keyname='test1').first()
         self.assertEqual(classobj.is_enabled, False)
 
@@ -162,7 +162,7 @@ class TestDataClass(TestCase):
               keyname: test1
               _action: enable
             ''')
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
         classobj = DataClass.objects.filter(keyname='test1').first()
         self.assertEqual(classobj.is_enabled, True)
 
@@ -173,7 +173,7 @@ class TestDataClass(TestCase):
               _action: disable
             ''')
         aaa = {'perms': ['p_schema_read']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         classobj = DataClass.objects.filter(keyname='test1').first()
         self.assertEqual(classobj.is_enabled, True)
@@ -188,7 +188,7 @@ class TestDataClass(TestCase):
                   _action: delete
             ''')
         aaa = {'perms': ['p_schema_write']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         obj = DataSchema.objects.filter(
             classname='test0', keyname='mystring').first()
@@ -205,7 +205,7 @@ class TestDataClass(TestCase):
                   _action: delete
             ''')
         aaa = {'perms': ['p_unknown_permission']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         instance = Instance.from_keyname(
             classname="test0", keyname="test0-01")
@@ -256,7 +256,7 @@ class TestDataClass(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_test1_delete']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         # removed from DB
         classobj = DataClass.objects.filter(keyname='test1').first()
@@ -278,7 +278,7 @@ class TestDataClass(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_test1_delete2']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         # not removed from DB
         classobj = DataClass.objects.filter(keyname='test1').first()
@@ -301,7 +301,7 @@ class TestDataClass(TestCase):
               _action: disable
             ''')
         aaa = {'perms': ['p_test1_update']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
         instance = Instance.from_keyname(
             classname="test1", keyname="test1-01")
         self.assertFalse(instance.is_enabled)
@@ -313,7 +313,7 @@ class TestDataClass(TestCase):
             ''')
 
         aaa = {'perms': ['p_test1_update']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
         instance = Instance.from_keyname(
             classname="test1", keyname="test1-01")
         self.assertTrue(instance.is_enabled)
@@ -325,7 +325,7 @@ class TestDataClass(TestCase):
               _action: disable
             ''')
         aaa = {'perms': ['p_test1_update']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
         instance = Instance.from_keyname(
             classname="test1", keyname="test1-01")
         self.assertFalse(instance.is_enabled)
@@ -336,7 +336,7 @@ class TestDataClass(TestCase):
               _action: enable
             ''')
         aaa = {'perms': ['p_test1_update2']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
         instance = Instance.from_keyname(
             classname="test1", keyname="test1-01")
         self.assertFalse(instance.is_enabled)
@@ -348,7 +348,7 @@ class TestDataClass(TestCase):
               _action: disable
             ''')
         aaa = {'perms': ['p_test1_update2']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         instance = Instance.from_keyname(
             classname="test1", keyname="test1-01")
