@@ -63,7 +63,7 @@ class IAMTestNoFixture(TestCase):
               email: user99@test.test
             ''')
         aaa = {'perms': ['p_user_create']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         login = user_get_login_by_email('user99@test.test')
         self.assertEqual(login, "user99")
@@ -92,7 +92,7 @@ class IAMTestNoFixture(TestCase):
               users : ['user01']
             ''')
         aaa = {'perms': ['p_group_create', 'p_user_create']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         user01 = user_get_by_login('user01')
         self.assertEqual(user01.login, 'user01')
@@ -124,7 +124,7 @@ class IAMTest(TestCase):
               _action: create
             ''')
         aaa = {'perms': ['p_user_create']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneUser.objects.filter(login='user99').first()
         self.assertIsNotNone(classobj)
@@ -136,7 +136,7 @@ class IAMTest(TestCase):
               _action: create
             ''')
         aaa = {'perms': ['p_iam_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneUser.objects.filter(login='user99').first()
         self.assertIsNone(classobj)
@@ -154,7 +154,7 @@ class IAMTest(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_user_delete']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneUser.objects.filter(login='testuser01').first()
         self.assertIsNone(classobj)
@@ -170,7 +170,7 @@ class IAMTest(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_ima_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneUser.objects.filter(login='testuser01').first()
         self.assertIsNotNone(classobj)
@@ -189,7 +189,7 @@ class IAMTest(TestCase):
               displayname: testnew
             ''')
         aaa = {'perms': ['p_user_update']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneUser.objects.filter(login='testuser01').first()
         self.assertEqual(classobj.displayname, "testnew")
@@ -206,7 +206,7 @@ class IAMTest(TestCase):
               displayname: testnew
             ''')
         aaa = {'perms': ['p_iam_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneUser.objects.filter(login='testuser01').first()
         self.assertNotEqual(classobj.displayname, "testnew")
@@ -244,14 +244,14 @@ class IAMTest(TestCase):
         gobj.save()
 
         gobj = group_get_by_name("group_unittest")
-        r = group_delete(gobj)
-        self.assertIsNot(r, False)
-        self.assertIsInstance(r, SireneGroup)
+        g, err = group_delete(gobj)
+        self.assertIsNot(err, False)
+        self.assertIsInstance(g, SireneGroup)
 
         # non-existent group
         gobj = group_get_by_name("group_unittest2")
-        r = group_delete(gobj)
-        self.assertEqual(r, False)
+        g, err = group_delete(gobj)
+        self.assertIn("group_delete", err)
 
     def test_group_delete_builtin(self):
 
@@ -259,8 +259,8 @@ class IAMTest(TestCase):
         gobj.is_builtin = True
         gobj.save()
 
-        r = group_delete(gobj)
-        self.assertEqual(r, False)
+        g,err = group_delete(gobj)
+        self.assertIn("builtin", err)
 
 
 # read
@@ -275,7 +275,7 @@ class IAMTest(TestCase):
               _action: create
             ''')
         aaa = {'perms': ['p_group_create']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='group99').first()
         self.assertIsNotNone(classobj)
@@ -287,7 +287,7 @@ class IAMTest(TestCase):
               _action: create
             ''')
         aaa = {'perms': ['p_iam_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='group99').first()
         self.assertIsNone(classobj)
@@ -305,7 +305,7 @@ class IAMTest(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_group_delete']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='testgroup01').first()
         self.assertIsNone(classobj)
@@ -321,7 +321,7 @@ class IAMTest(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_iam_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='testgroup01').first()
         self.assertIsNotNone(classobj)
@@ -340,7 +340,7 @@ class IAMTest(TestCase):
               displayname: testnew
             ''')
         aaa = {'perms': ['p_group_update']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='testgroup01').first()
         self.assertEqual(classobj.displayname, "testnew")
@@ -357,7 +357,7 @@ class IAMTest(TestCase):
               displayname: testnew
             ''')
         aaa = {'perms': ['p_iam_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='testgroup01').first()
         self.assertNotEqual(classobj.displayname, "testnew")
@@ -379,7 +379,7 @@ class IAMTest(TestCase):
               _action: create
             ''')
         aaa = {'perms': ['p_role_create']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='role99').first()
         self.assertIsNotNone(classobj)
@@ -391,7 +391,7 @@ class IAMTest(TestCase):
               _action: create
             ''')
         aaa = {'perms': ['p_iam_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='role99').first()
         self.assertIsNone(classobj)
@@ -409,7 +409,7 @@ class IAMTest(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_role_delete']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='role_test_01').first()
         self.assertIsNone(classobj)
@@ -425,7 +425,7 @@ class IAMTest(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_iam_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='role_test_01').first()
         self.assertIsNotNone(classobj)
@@ -444,7 +444,7 @@ class IAMTest(TestCase):
               displayname: testnew
             ''')
         aaa = {'perms': ['p_role_update']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='role_test_01').first()
         self.assertEqual(classobj.displayname, "testnew")
@@ -461,7 +461,7 @@ class IAMTest(TestCase):
               displayname: testnew
             ''')
         aaa = {'perms': ['p_iam_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SireneGroup.objects.filter(keyname='role_test_01').first()
         self.assertNotEqual(classobj.displayname, "testnew")
@@ -483,7 +483,7 @@ class IAMTest(TestCase):
               _action: create
             ''')
         aaa = {'perms': ['p_permission_create']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SirenePermission.objects.filter(
             keyname='permission99').first()
@@ -496,7 +496,7 @@ class IAMTest(TestCase):
               _action: create
             ''')
         aaa = {'perms': ['p_iam_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SirenePermission.objects.filter(
             keyname='permission99').first()
@@ -519,7 +519,7 @@ class IAMTest(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_permission_delete']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SirenePermission.objects.filter(
             keyname='p_unittest').first()
@@ -540,7 +540,7 @@ class IAMTest(TestCase):
               _action: delete
             ''')
         aaa = {'perms': ['p_iam_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SirenePermission.objects.filter(
             keyname='p_unittest').first()
@@ -561,7 +561,7 @@ class IAMTest(TestCase):
               displayname: testnew
             ''')
         aaa = {'perms': ['p_permission_update']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SirenePermission.objects.filter(
             keyname='p_log_view').first()
@@ -580,7 +580,7 @@ class IAMTest(TestCase):
               displayname: testnew
             ''')
         aaa = {'perms': ['p_iam_access']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         classobj = SirenePermission.objects.filter(
             keyname='p_log_view').first()
