@@ -40,7 +40,7 @@ class Autogroup(TestCase):
                 'p_user_create',
                 'p_schema_write',
                 'p_data_admin']}
-        _ = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
     def test_no_grammar(self):
 
