@@ -69,7 +69,7 @@ class PipelineCRUD(TestCase):
                   - field_noop                                                   
             ''')
         aaa = {'perms':['p_pipeline_create']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         pipelines = list_pipelines(is_enabled=True)
         self.assertEqual ( len(pipelines), 1)
@@ -95,7 +95,7 @@ class PipelineCRUD(TestCase):
                   - discard: ['']
             ''')
         aaa = {'perms':['p_pipeline_create']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         datalist = [
             {'a':5, 'b':6},
@@ -122,7 +122,7 @@ class PipelineCRUD(TestCase):
                   - field_set: ['CONDITION_TEST', b, 'testok']
             ''')
         aaa = {'perms':['p_pipeline_create']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         datalist = [
             {'a':'test'},
@@ -149,7 +149,7 @@ class PipelineCRUD(TestCase):
                   - field_set: ['!CONDITION_TEST', b, 'testok']
             ''')
         aaa = {'perms':['p_pipeline_create']}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         datalist = [
             {'a':'unit'},
