@@ -30,7 +30,7 @@ class TestSchemaLoader(TestCase):
 
         aaa = {'perms': ['p_schema_write']}
 
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         # Verify schema was created
         self.assertTrue(Schema.exists('testschema_minimal'))
@@ -60,7 +60,7 @@ class TestSchemaLoader(TestCase):
         aaa = {'perms': [
             'p_schema_write',
             ]}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         # Verify schema was created
         self.assertTrue(Schema.exists('testschema'))
@@ -85,7 +85,7 @@ class TestSchemaLoader(TestCase):
         aaa = {'perms': [
             'p_schema_write',
             ]}
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         # Verify schema was created
         self.assertTrue(Schema.exists('testschemaupdated'))
@@ -101,7 +101,7 @@ class TestSchemaLoader(TestCase):
         }
 
         datalist_update = [yaml_entry_update]
-        load_broker(datalist=datalist_update, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_update, aaa=aaa)
 
         # Verify displayname was updated
         schema_updated = Schema.from_name('testschemaupdated')
@@ -127,7 +127,7 @@ class TestSchemaLoader(TestCase):
             ]}
 
         # First init - should create schema
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         # Verify schema was created
         self.assertTrue(Schema.exists('testschemainit'))
@@ -145,7 +145,7 @@ class TestSchemaLoader(TestCase):
         }
 
         datalist_second = [yaml_entry_second]
-        load_broker(datalist=datalist_second, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_second, aaa=aaa)
 
         # Verify displayname was NOT changed (init action skips if exists)
         schema_second = Schema.from_name('testschemainit')
@@ -171,7 +171,7 @@ class TestSchemaLoader(TestCase):
             ]}
 
         # Try to update non-existent schema - should fail silently
-        result = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        _ = load_broker(datalist=datalist, aaa=aaa)
 
         # Verify schema was NOT created
         self.assertFalse(Schema.exists('testschemaupdate'))
@@ -185,7 +185,7 @@ class TestSchemaLoader(TestCase):
         }
 
         datalist_create = [yaml_entry_create]
-        load_broker(datalist=datalist_create, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_create, aaa=aaa)
 
         # Verify schema was created
         self.assertTrue(Schema.exists('testschemaupdate'))
@@ -201,7 +201,7 @@ class TestSchemaLoader(TestCase):
         }
 
         datalist_update = [yaml_entry_update]
-        load_broker(datalist=datalist_update, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_update, aaa=aaa)
 
         # Verify displayname was updated
         schema_updated = Schema.from_name('testschemaupdate')
@@ -227,7 +227,7 @@ class TestSchemaLoader(TestCase):
             'p_schema_write',
             ]}
 
-        load_broker(datalist=datalist_create, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_create, aaa=aaa)
 
         # Verify schema was created
         self.assertTrue(Schema.exists('testschemadelete'))
@@ -242,7 +242,7 @@ class TestSchemaLoader(TestCase):
         }
 
         datalist_delete = [yaml_entry_delete]
-        load_broker(datalist=datalist_delete, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_delete, aaa=aaa)
 
         # Verify schema was deleted
         self.assertFalse(Schema.exists('testschemadelete'))
@@ -268,7 +268,7 @@ class TestSchemaLoader(TestCase):
             'p_schema_write',
             ]}
 
-        load_broker(datalist=datalist_create, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_create, aaa=aaa)
 
         # Verify schema was created and is enabled
         self.assertTrue(Schema.exists('testschemadisable'))
@@ -284,7 +284,7 @@ class TestSchemaLoader(TestCase):
         }
 
         datalist_disable = [yaml_entry_disable]
-        load_broker(datalist=datalist_disable, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_disable, aaa=aaa)
 
         # Verify schema is still there but disabled
         self.assertTrue(Schema.exists('testschemadisable'))
@@ -311,7 +311,7 @@ class TestSchemaLoader(TestCase):
             'p_schema_write',
             ]}
 
-        load_broker(datalist=datalist_create, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_create, aaa=aaa)
 
         # Disable it
         yaml_entry_disable = {
@@ -321,7 +321,7 @@ class TestSchemaLoader(TestCase):
         }
 
         datalist_disable = [yaml_entry_disable]
-        load_broker(datalist=datalist_disable, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_disable, aaa=aaa)
 
         # Verify schema is disabled
         schema = Schema.from_name('testschemaenable')
@@ -335,7 +335,7 @@ class TestSchemaLoader(TestCase):
         }
 
         datalist_enable = [yaml_entry_enable]
-        load_broker(datalist=datalist_enable, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_enable, aaa=aaa)
 
         # Verify schema is now enabled
         schema_enabled = Schema.from_name('testschemaenable')
@@ -360,11 +360,11 @@ class TestSchemaLoader(TestCase):
             'p_schema_write',
             ]}
 
-        result = load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        result = load_broker(datalist=datalist, aaa=aaa)
 
         # Verify no schema was created (result should be 0 for unknown action)
         # load_broker returns count of processed items, which is 0 for unknown action
-        self.assertEqual(result, 0)
+        self.assertEqual(result['count_ok'], 0)
         self.assertFalse(Schema.exists('testschema'))
 
 
@@ -399,7 +399,7 @@ class TestSchemaLoader(TestCase):
             'p_schema_write',
             ]}
 
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         # Verify schema was created
         self.assertTrue(Schema.exists('testschemaattributes'))
@@ -450,7 +450,7 @@ class TestSchemaLoader(TestCase):
             'p_schema_write',
             ]}
 
-        load_broker(datalist=datalist, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist, aaa=aaa)
 
         # Verify schema was created
         self.assertTrue(Schema.exists('testschemafield'))
@@ -494,7 +494,7 @@ class TestSchemaLoader(TestCase):
 
         aaa = {'perms': ['p_schema_write']}
 
-        load_broker(datalist=datalist_create, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_create, aaa=aaa)
 
         # Step 2: Verify schema and fields are created in database
         # Check DataClass exists
@@ -523,7 +523,7 @@ class TestSchemaLoader(TestCase):
         }
 
         datalist_delete = [yaml_entry_delete]
-        load_broker(datalist=datalist_delete, aaa=aaa, verbose=False)
+        load_broker(datalist=datalist_delete, aaa=aaa)
 
         # Step 4: Verify schema and fields are removed from database
         # Check DataClass is deleted
