@@ -8,12 +8,8 @@ from django.core.cache import cache as cache_django
 
 from tests import helper
 
-
-from app_home.configuration import get_configuration
 import app_home.cache as cache
 
-from app_user.models import SireneUser
-from app_user.role import role_get_by_name
 
 
 class AppStatusTest(TestCase):
